@@ -1,4 +1,3 @@
-
 ## -----------------------------------------------------------------------------
 
 test_that("anova filtering and logging", {
@@ -11,18 +10,18 @@ test_that("anova filtering and logging", {
   folds <- vfold_cv(mtcars, v = 5, repeats = 2)
   fold_att <- attributes(folds)
   spec <-
-    decision_tree(cost_complexity = tune(), min_n = tune()) %>%
-    set_engine("rpart") %>%
+    decision_tree(cost_complexity = tune(), min_n = tune()) |>
+    set_engine("rpart") |>
     set_mode("regression")
-  wflow <- workflow() %>%
-    add_model(spec) %>%
+  wflow <- workflow() |>
+    add_model(spec) |>
     add_formula(mpg ~ .)
   grid <- expand.grid(cost_complexity = c(0.001, 0.01), min_n = c(2:5))
 
   ## -----------------------------------------------------------------------------
 
   grid_res <-
-    spec %>% tune_grid(mpg ~ ., folds, grid = grid, metrics = metric_set(rmse))
+    spec |> tune_grid(mpg ~ ., folds, grid = grid, metrics = metric_set(rmse))
   # Pull out rmse values, format them to emulate the racing tests then
   # use lme4 package to create the model results for removing configurations.
 
@@ -38,7 +37,12 @@ test_that("anova filtering and logging", {
   rmse_summary <- summary(rmse_mod)$coef
   rmse_res <- tibble::as_tibble(rmse_summary)
   rmse_res$.config <- gsub("\\.config", "", rownames(rmse_summary))
-  rmse_res$.config <- gsub("(Intercept)", configs[1], rmse_res$.config, fixed = TRUE)
+  rmse_res$.config <- gsub(
+    "(Intercept)",
+    configs[1],
+    rmse_res$.config,
+    fixed = TRUE
+  )
   rmse_ci <- confint(rmse_mod, level = 1 - alpha, method = "Wald", quiet = TRUE)
   rmse_ci <- rmse_ci[grepl("config", rownames(rmse_ci)), ]
 
@@ -54,12 +58,10 @@ test_that("anova filtering and logging", {
   # ------------------------------------------------------------------------------
   # top-level anova filter interfaces
 
-  expect_error({
+  expect_snapshot({
     set.seed(129)
-    anova_mod <- spec %>% tune_race_anova(mpg ~ ., folds, grid = grid)
-  },
-  regexp = NA
-  )
+    anova_mod <- spec |> tune_race_anova(mpg ~ ., folds, grid = grid)
+  })
   expect_true(inherits(anova_mod, "tune_race"))
   expect_true(inherits(anova_mod, "tune_results"))
   expect_true(tibble::is_tibble((anova_mod)))
@@ -67,10 +69,11 @@ test_that("anova filtering and logging", {
   expect_silent({
     set.seed(129)
     anova_wlfow <-
-      wflow %>%
-      tune_race_anova(folds,
-                      grid = grid,
-                      control = control_race(verbose_elim = FALSE, save_pred = TRUE)
+      wflow |>
+      tune_race_anova(
+        folds,
+        grid = grid,
+        control = control_race(verbose_elim = FALSE, save_pred = TRUE)
       )
   })
   expect_true(inherits(anova_wlfow, "tune_race"))
@@ -78,12 +81,11 @@ test_that("anova filtering and logging", {
   expect_true(tibble::is_tibble((anova_wlfow)))
   expect_true(sum(names(anova_wlfow) == ".predictions") == 1)
 
-
   ## -----------------------------------------------------------------------------
   ## anova formula
 
   for (i in 2:nrow(folds)) {
-    f <- finetune:::lmer_formula(folds %>% slice(1:i), fold_att)
+    f <- finetune:::lmer_formula(folds |> slice(1:i), fold_att)
     if (i < 7) {
       expect_equal(f, .estimate ~ .config + (1 | .all_id), ignore_attr = TRUE)
     } else {
@@ -97,7 +99,7 @@ test_that("anova filtering and logging", {
   car_att <- attributes(car_bt)
 
   for (i in 2:nrow(car_bt)) {
-    f <- finetune:::lmer_formula(car_bt %>% slice(1:i), car_att)
+    f <- finetune:::lmer_formula(car_bt |> slice(1:i), car_att)
     expect_equal(f, .estimate ~ .config + (1 | id), ignore_attr = TRUE)
   }
   expect_equal(environment(f), rlang::base_env())
@@ -117,6 +119,7 @@ test_that("anova filtering and logging", {
   anova_res <- finetune:::test_parameters_gls(ames_grid_search)
   expect_equal(
     names(anova_res),
+    # fmt: skip
     c(
       ".config", "lower", "upper", "estimate", "pass", "K", "weight_func",
       "dist_power", "lon", "lat"
@@ -125,28 +128,35 @@ test_that("anova filtering and logging", {
   expect_equal(nrow(anova_res), nrow(ames_grid_res))
   expect_equal(anova_res$lower <= 0, anova_res$pass)
   expect_equal(
-    anova_res %>% dplyr::select(!!!param, .config) %>% arrange(.config),
-    ames_grid_res %>% dplyr::select(!!!param, .config) %>% arrange(.config)
+    anova_res |> dplyr::select(!!!param, .config) |> arrange(.config),
+    ames_grid_res |> dplyr::select(!!!param, .config) |> arrange(.config)
   )
 
   expect_snapshot(
     finetune:::log_racing(
-      control_race(verbose_elim = TRUE), anova_res,
-      ames_grid_search$splits, 10, "rmse"
+      control_race(verbose_elim = TRUE),
+      anova_res,
+      ames_grid_search$splits,
+      10,
+      "rmse"
     )
   )
   expect_snapshot(
     finetune:::log_racing(
-      control_race(verbose_elim = TRUE), anova_res,
-      ames_grid_search$splits, 10, "rmse"
+      control_race(verbose_elim = TRUE),
+      anova_res,
+      ames_grid_search$splits,
+      10,
+      "rmse"
     )
   )
   expect_snapshot(
     finetune:::log_racing(
-      control_race(verbose_elim = TRUE), anova_res,
-      ames_grid_search$splits, 10, "rmse"
+      control_race(verbose_elim = TRUE),
+      anova_res,
+      ames_grid_search$splits,
+      10,
+      "rmse"
     )
   )
-
 })
-
