@@ -10,21 +10,23 @@ test_that("top-level win/loss filter interfaces", {
   set.seed(2332)
   folds <- vfold_cv(mtcars, v = 5, repeats = 2)
   fold_att <- attributes(folds)
-  spec <- decision_tree(cost_complexity = tune(), min_n = tune()) %>%
-    set_engine("rpart") %>%
+  spec <- decision_tree(cost_complexity = tune(), min_n = tune()) |>
+    set_engine("rpart") |>
     set_mode("regression")
-  wflow <- workflow() %>%
-    add_model(spec) %>%
+  wflow <- workflow() |>
+    add_model(spec) |>
     add_formula(mpg ~ .)
   grid <- expand.grid(cost_complexity = c(0.001, 0.01), min_n = c(2:5))
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
+  rec <- recipe(mpg ~ ., data = mtcars) |>
     step_normalize(all_predictors())
-  prm <- extract_parameter_set_dials(wflow) %>% update(min_n = min_n(c(2, 20)))
+  prm <- extract_parameter_set_dials(wflow) |> update(min_n = min_n(c(2, 20)))
 
   # ------------------------------------------------------------------------------
 
   set.seed(129)
-  suppressWarnings(wl_mod <- spec %>% tune_race_win_loss(mpg ~ ., folds, grid = grid))
+  suppressWarnings(
+    wl_mod <- spec |> tune_race_win_loss(mpg ~ ., folds, grid = grid)
+  )
 
   expect_true(inherits(wl_mod, "tune_race"))
   expect_true(inherits(wl_mod, "tune_results"))
@@ -36,9 +38,11 @@ test_that("top-level win/loss filter interfaces", {
     set.seed(129)
     suppressWarnings(
       wl_wlfow <-
-        wflow %>%
-        tune_race_win_loss(folds,
-          grid = grid, param_info = prm,
+        wflow |>
+        tune_race_win_loss(
+          folds,
+          grid = grid,
+          param_info = prm,
           control = control_race(verbose_elim = FALSE, save_pred = TRUE)
         )
     )
@@ -55,8 +59,10 @@ test_that("top-level win/loss filter interfaces", {
     set.seed(129)
     suppressMessages(
       wl_rec <-
-        spec %>%
-        tune_race_win_loss(rec, folds,
+        spec |>
+        tune_race_win_loss(
+          rec,
+          folds,
           grid = expand.grid(cost_complexity = c(.0001, .001), min_n = c(3, 5)),
           param_info = prm,
           control = control_race(
